@@ -3,7 +3,7 @@
 import numpy as np
 import pandas as pd
 
-from agora.base import ParametersABC, ProcessABC
+from agora.abc import ParametersABC, ProcessABC
 
 
 class birthsParameters(ParametersABC):
